function animate_ptsalsim(gg,yyyy,rg)
% animate_ptsalsim(gg,yyyy,rg)
% 
% Plots a quick animation of the sea-surface temperature from an ISDE ROMS simulation 
% INPUTS:
% gg = grid choice as a string (i.e., '200m' or '66m')
% yyyy = year of simulation as a string (i.e., '2000' or '2017')
% rg = range and interval for plotting as numerical vector (i.e., [1:100] or [1:5:1000])
% 
% OUTPUT:
% Quick sequence of figures to your screen
%
% EXAMPLE USAGE:
% gg = '66m';yyyy = '2015';rg = [1:5:1000];
% animate_ptsalsim(gg,yyyy,rg)
%
%
fname = sprintf('ROMS_%s_%s_sst.mat',gg,yyyy);
load(fname);

figure
for xx = rg
imagesc(lon(:,1),lat(1,:),squeeze(STEMP(:,:,xx))')
set(gca,'YDir','normal')
hold on
contour(lon,lat,mask,[1 1],'m')
contour(lon,lat,mask,[1 1],'m','linewidth',2)
caxis([10 20]);colorbar;grid on
title(sprintf('ISDE grid %s, Y %s - %s',gg, yyyy,datestr(Time(xx))))
pause(0.1);clf
end