function make_ptsaldeptime(gg,xx,yy)
% make_ptsaldeptime(gg,xx,yy)
% 
% Plots a depth-time plot of temperature, u, v, from a single location within an ISDE ROMS simulation 
% INPUTS:
% gg = grid choice as a string (i.e., '200m' or '66m')
% xx = spatial index, first dimension
% yy = spatial index, second dimension
%
% OUTPUT:
% Single plot to your screen
%
% EXAMPLE USAGE:
% gg = '200m';xx= 40; yy = 40
% make_ptsaldeptime(gg,xx,yy)
%
%
eval(sprintf('A = matfile(''ROMS_%s_2017_t4D.mat'');',gg));
eval(sprintf('B = matfile(''ROMS_%s_2017_u4D.mat'');',gg));
eval(sprintf('C = matfile(''ROMS_%s_2017_v4D.mat'');',gg));

temp = squeeze(A.TEMP(xx,yy,:,:));
u = squeeze(B.U(xx,yy,:,:));
v = squeeze(C.V(xx,yy,:,:));
zz = squeeze(A.ZTEMP(xx,yy,:,:));
time = A.Time;

figure
subplot(3,2,[1 3 5])
contour(A.lon,A.lat,A.mask,[1 1],'m','linewidth',2)
hold on
plot(A.lon(xx,yy),A.lat(xx,yy),'ok','markerfacecolor','r');grid on
title(sprintf('ISDE grid %s. Water depth is approx %3.2f m',gg,min(mean(zz'))))
subplot(3,2,2)
pcolor(time,zz,temp);caxis([5 20]);colorbar;grid on
title(sprintf('Temp at %3.2f,%3.2f (^oC)',A.lon(xx,yy),A.lat(xx,yy)))
datetick('x','mm/dd','keeplimits','keepticks');grid on;ylabel('Depth (m)')
subplot(3,2,4)
pcolor(time,zz,u);caxis([-.5 .5]);colorbar;grid on
title(sprintf('u at %3.2f,%3.2f (m/s)',A.lon(xx,yy),A.lat(xx,yy)))
datetick('x','mm/dd','keeplimits','keepticks');grid on;ylabel('Depth (m)')
subplot(3,2,6)
pcolor(time,zz,v);caxis([-.5 .5]);colorbar;grid on
title(sprintf('v at %3.2f,%3.2f (m/s)',A.lon(xx,yy),A.lat(xx,yy)))
datetick('x','mm/dd','keeplimits','keepticks');grid on;ylabel('Depth (m)')
xlabel('mm/dd')
