function make_ptsaltrans(gg,yy,tt)
% make_ptsaltrans(gg,yy,tt)
% 
% Plots a depth-time plot of temperature, u, v, from a single location within an ISDE ROMS simulation 
% INPUTS:
% gg = grid choice as a string (i.e., '200m' or '66m')
% yy = spatial index, second dimension (essentially latitude)
%
% OUTPUT:
% Single plot to your screen
%
% EXAMPLE USAGE:
% gg = '200m';yy= 40;tt = 10
% make_ptsaltrans(gg,yy,tt)
%
%
eval(sprintf('A = matfile(''ROMS_%s_2017_t4D.mat'');',gg));
eval(sprintf('B = matfile(''ROMS_%s_2017_u4D.mat'');',gg));
eval(sprintf('C = matfile(''ROMS_%s_2017_v4D.mat'');',gg));

temp = squeeze(A.TEMP(:,yy,:,tt));
u = squeeze(B.U(:,yy,:,tt));
v = squeeze(C.V(:,yy,:,tt));
zz = squeeze(A.ZTEMP(:,yy,:,tt));
time = A.Time;
lons = squeeze(A.lon(:,yy));

sz = size(zz);


 figure
 subplot(3,2,[1 3 5])
 contour(A.lon,A.lat,A.mask,[1 1],'m','linewidth',2)
 hold on
 plot([lons(1) lons(end)],[A.lat(1,yy) A.lat(1,yy)],'--r','linewidth',2);grid on
 title(sprintf('ISDE grid %s. Lat %3.2f',gg,A.lat(1,yy)))
 subplot(3,2,2)
pcolor(repmat(lons,[1 sz(2)]),zz,temp);caxis([10 20]);colorbar;grid on
title(sprintf('Temp (^oC) at Lat %3.2f, time = %s',A.lat(1,yy),datestr(time(tt),'mm/dd/yy')))
ylabel('Depth (m)');shading flat
 subplot(3,2,4)
pcolor(repmat(lons,[1 sz(2)]),zz,u);caxis([-.5 .5]);colorbar;grid on
title(sprintf('u (m/s) at Lat %3.2f, time = %s',A.lat(1,yy),datestr(time(tt),'mm/dd/yy')))
ylabel('Depth (m)');shading flat
 subplot(3,2,6)
pcolor(repmat(lons,[1 sz(2)]),zz,v);caxis([-.5 .5]);colorbar;grid on
title(sprintf('v (m/s) at Lat %3.2f, time = %s',A.lat(1,yy),datestr(time(tt),'mm/dd/yy')))
ylabel('Depth (m)');xlabel('Lon');shading flat
